@@ -169,14 +169,28 @@ class ADBClient(object):
             return dict(map(lambda x: x.split("=", 1), output.splitlines()))
         return None
 
+    def get_system_settings(self) -> Optional[Dict[str, str]]:
+        code, output, error = self.shell("settings list system")
+        if code == ADBCommandResult.RESULT_OK and output:
+            return dict(map(lambda x: x.split("=", 1), output.splitlines()))
+        return None
+
     def get_global_settings_value(self, key: str):
         """Retrieve a value from the device global settings"""
         return self.shell(f"settings get global {key}")
 
+    def get_system_settings_value(self, key: str):
+        """Retrieve a value from the device system settings"""
+        return self.shell(f"settings get system {key}")
+
     def set_global_settings_value(self, key: str, value: str):
         self.root()
         return self.shell(f"settings put global {key} {value}")
 
+    def set_system_settings_value(self, key: str, value: str):
+        self.root()
+        return self.shell(f"settings put system {key} {value}")
+
     def dumpsys_bluetooth(self):
         return self.dumpsys("bluetooth_manager")
 
@@ -197,6 +211,17 @@ class ADBClient(object):
     def ifconfig(self):
         return self.shell("ifconfig")
 
+    def gc(self, pid: int) -> bool:
+        """Force the GC for the given pid"""
+        return self.shell(f"kill -10 {pid}").is_ok()
+
+    def pid(self, packagename: str) -> int:
+        """Retrieve the pid of the given package or -1 if not found"""
+        result = self.shell(f"pidof -s {packagename}")
+        if result.is_ok():
+            return int(result.output())
+        return -1
+
     """ -----------------------------------------------------------------------"""
     """ File system methods """
     """ -----------------------------------------------------------------------"""
@@ -216,8 +241,8 @@ class ADBClient(object):
     def remove(self, dst: str):
         return self.shell(f"rm -fr {dst}")
 
-    def cat(self, filename: str) -> str:
-        code, output, error = self.shell(f"cat {filename}")
+    def cat(self, filename: str, encoding: str = 'utf-8') -> str:
+        code, output, error = self.shell(f"cat {filename}", encoding=encoding)
         if code != ADBCommandResult.RESULT_OK:
             raise IOError(f"File {filename} not found")
         return output
